@@ -27,8 +27,7 @@
 
 drop_detect <- function(data, last_col = NULL) {
 
-  data <- data |>
-    dplyr::mutate(dplyr::across(dplyr::everything(), as.character))
+  data <- dplyr::mutate(data, dplyr::across(dplyr::everything(), as.character))
 
  if (is.null(last_col)) {
   while (ncol(data) > 0) {
@@ -36,7 +35,7 @@ drop_detect <- function(data, last_col = NULL) {
    last_col_name <- colnames(data)[last_col]
 
    if (all(!is.na(data[, last_col]))) {
-    data <- data |> dplyr::select(-last_col)
+    data <- dplyr::select(data, -{{last_col}})
    } else {
     warning(paste("last_col set to", last_col_name))
     break
@@ -44,12 +43,10 @@ drop_detect <- function(data, last_col = NULL) {
   }
  } else {
   # Select all columns up to last_col
-  data <- data |> dplyr::select(1:last_col)
+  data <- dplyr::select(data, 1:{{last_col}})
  }
 
- result <- data |>
-  find_dropouts() |>
-  tibble::tibble()
+ result <- tibble::tibble(find_dropouts(data))
 
  return(result)
 }
